@@ -1,7 +1,7 @@
 /*============================================================================
 
-  WCSLIB 4.13 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2012, Mark Calabretta
+  WCSLIB 4.18 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2013, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -16,22 +16,16 @@
   more details.
 
   You should have received a copy of the GNU Lesser General Public License
-  along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+  along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Correspondence concerning WCSLIB may be directed to:
-    Internet email: mcalabre@atnf.csiro.au
-    Postal address: Dr. Mark Calabretta
-                    Australia Telescope National Facility, CSIRO
-                    PO Box 76
-                    Epping NSW 1710
-                    AUSTRALIA
+  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
 
-  Author: Mark Calabretta, Australia Telescope National Facility
-  http://www.atnf.csiro.au/~mcalabre/index.html
+  Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
+  http://www.atnf.csiro.au/people/Mark.Calabretta
   $Id$
 *=============================================================================
 *
-* WCSLIB 4.13 - C routines that implement the FITS World Coordinate System
+* WCSLIB 4.18 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to
 *
 *   "Representations of world coordinates in FITS",
@@ -163,7 +157,8 @@
 *                           3: As above, but also report all non-WCS
 *                              keyrecords that were discarded, and the number
 *                              of coordinate representations (nwcs) found.
-*                       The report is written to stderr.
+*                       The report is written to stderr by default, or the
+*                       stream set by wcsprintf_set().
 *
 *                       For ctrl < 0, WCS keyrecords processed by wcspih()
 *                       are removed from header[]:
@@ -291,7 +286,8 @@
 *                           3: As above, but also report all non-WCS
 *                              keyrecords that were discarded, and the number
 *                              of coordinate representations (nwcs) found.
-*                       The report is written to stderr.
+*                       The report is written to stderr by default, or the
+*                       stream set by wcsprintf_set().
 *
 *                       For ctrl < 0, WCS keyrecords processed by wcsbth()
 *                       are removed from header[]:
@@ -430,9 +426,9 @@
 *      - WCSHDR_all: Accept all extensions recognized by the parser.
 *
 *      - WCSHDR_reject: Reject non-standard keywords (that are not otherwise
-*              accepted).  A message will optionally be printed on stderr, as
-*              determined by the ctrl argument, and nreject will be
-*              incremented.
+*              accepted).  A message will optionally be printed on stderr by
+*              default, or the stream set by wcsprintf_set(), as determined by
+*              the ctrl argument, and nreject will be incremented.
 *
 *              This flag may be used to signal the presence of non-standard
 *              keywords, otherwise they are simply passed over as though they
